========================
Ceygen API Documentation
========================

.. toctree::
   :maxdepth: 2

   README
   core
   elemwise
   lu

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
